@@ -3,7 +3,7 @@ library(SVEMnet)
 
 # Example data
 data <- iris
-svem_model <- SVEMnet(Sepal.Length ~ ., data = data, nBoot = 300)
+svem_model <- SVEMnet(Sepal.Length ~ ., data = data, relaxed=FALSE,glmnet_alpha=c(1),nBoot = 50)
 coef(svem_model)
 
 ## ----fig.width=6, fig.height=4------------------------------------------------
@@ -19,9 +19,3 @@ knitr::include_graphics("figures/whole_model_test.png")
 ## ----echo=FALSE, out.width='100%', fig.cap="Whole Model Test Results for Example 2"----
 knitr::include_graphics("figures/whole_model_2.png")
 
-## ----show-file6, echo=FALSE, results='asis'-----------------------------------
-raw_file6 <- readLines("bic_sim.R")
-cat("```r\n")
-cat(raw_file6, sep="\n")
-cat("\n```\n")
-
